@@ -137,7 +137,7 @@ void eval_installed_file (char *file)
   
   relative = g_strconcat (GAMESDIR, file, NULL);
   installed_filename = gnome_program_locate_file (NULL, 
-                                                  GNOME_FILE_DOMAIN_DATADIR,
+                                                  GNOME_FILE_DOMAIN_APP_DATADIR,
                                                   relative,
                                                   FALSE, NULL);
 
@@ -506,8 +506,11 @@ int main (int argc, char *argv [])
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  gnome_init_with_popt_table ("Aisleriot", VERSION, argc, argv,
-			      aisleriot_opts, 0, NULL);
+   gnome_program_init ("aisleriot", VERSION,
+ 		      LIBGNOMEUI_MODULE, 
+ 		      argc, argv,
+ 		      GNOME_PARAM_POPT_TABLE, aisleriot_opts,
+ 		      GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
 
   gtk_widget_push_colormap (gdk_rgb_get_colormap ());
 
@@ -524,7 +527,7 @@ int main (int argc, char *argv [])
 
   retrieve_state (gnome_master_client ());
 
-  dir = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_DATADIR,
+  dir = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
 	                                        GAMESDIR, FALSE, NULL);
 
   records = scandir (dir, &game_dents, is_game, alphasort);
