@@ -50,7 +50,7 @@ image_widget_setup (char *name)
 	char *filename = NULL;
 
 	filename = gnome_program_locate_file (NULL,
-			GNOME_FILE_DOMAIN_PIXMAP, name,
+			GNOME_FILE_DOMAIN_APP_PIXMAP, name,
 			TRUE, NULL);
 	if (filename != NULL)
 		pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
@@ -260,7 +260,7 @@ about(GtkWidget *widget, gpointer data)
 	       char *filename = NULL;
 
 	       filename = gnome_program_locate_file (NULL,
-			       GNOME_FILE_DOMAIN_PIXMAP,  ("gnome-gnomine.png"),
+			       GNOME_FILE_DOMAIN_APP_PIXMAP,  ("gnome-gnomine.png"),
 			       TRUE, NULL);
 	       if (filename != NULL)
 	       {
@@ -615,7 +615,7 @@ main (int argc, char *argv[])
 			LIBGNOMEUI_MODULE,
 			argc, argv,
 			GNOME_PARAM_POPT_TABLE, options,
-			NULL);
+			GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
 
 	/* Get the default GConfClient */
 	conf_client = gconf_client_get_default ();
