@@ -20,6 +20,8 @@
 #include <config.h>
 #include <gnome.h>
 #include <libgnomeui/gnome-window-icon.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <games-clock.h>
 #include <time.h>
 
 #define APPNAME "gnotravex"
@@ -97,6 +99,7 @@ void game_score();
 gint timer_cb();
 void timer_start();
 void pause_cb();
+void gui_draw_pause();
 static int save_state(GnomeClient*, gint, GnomeRestartStyle, gint, GnomeInteractStyle, gint, gpointer);
 
 
@@ -121,7 +124,7 @@ GnomeUIInfo game_menu[] = {
 
   { GNOME_APP_UI_ITEM, N_("Sol_ve"), N_("Solve the game"),
     solve_cb, NULL, NULL,GNOME_APP_PIXMAP_STOCK,
-    GNOME_STOCK_MENU_REFRESH, 0, 0, NULL },
+    GTK_STOCK_REFRESH, 0, 0, NULL },
 
   GNOMEUIINFO_SEPARATOR,
 
@@ -129,7 +132,7 @@ GnomeUIInfo game_menu[] = {
 
   GNOMEUIINFO_SEPARATOR,
 
-  GNOMEUIINFO_MENU_EXIT_ITEM(quit_game_cb, NULL),
+  GNOMEUIINFO_MENU_QUIT_ITEM(quit_game_cb, NULL),
 
   GNOMEUIINFO_END
 };
@@ -203,17 +206,22 @@ int main (int argc, char **argv){
 
   gnome_score_init(APPNAME);
 
-  bindtextdomain(PACKAGE, GNOMELOCALEDIR);
-  textdomain(PACKAGE);
+  bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+  textdomain(GETTEXT_PACKAGE);
 
-  gnome_init_with_popt_table(APPNAME, VERSION, argc, argv, options, 0, NULL);
+  gnome_program_init (APPNAME, VERSION,
+      		      LIBGNOMEUI_MODULE, 
+       		      argc, argv,
+       		      GNOME_PARAM_POPT_TABLE, options,
+       		      GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
+     
   gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnotravex/gnome-gnotravex.png");
   client = gnome_master_client();
-  gtk_object_ref(GTK_OBJECT(client));
-  gtk_object_sink(GTK_OBJECT(client));
+  g_object_ref(G_OBJECT(client));
   
-  gtk_signal_connect(GTK_OBJECT (client), "save_yourself", GTK_SIGNAL_FUNC (save_state), argv[0]);
-  gtk_signal_connect(GTK_OBJECT(client), "die", GTK_SIGNAL_FUNC(quit_game_cb), argv[0]);
+  g_signal_connect(G_OBJECT (client), "save_yourself", G_CALLBACK (save_state), argv[0]);
+  g_signal_connect(G_OBJECT(client), "die", G_CALLBACK(quit_game_cb), argv[0]);
 
   if(SIZE<2 || SIZE>6) SIZE=3;
   
@@ -232,7 +240,7 @@ int main (int argc, char **argv){
 
   new_game_cb(space,NULL);
   
-  gtk_check_menu_item_set_state(GTK_CHECK_MENU_ITEM(size_radio_list[SIZE-2].widget),TRUE);
+  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(size_radio_list[SIZE-2].widget),TRUE);
 
   gtk_main ();
   
@@ -243,11 +251,11 @@ void create_window(){
   window = gnome_app_new(APPNAME, N_(APPNAME_LONG));
   gtk_window_set_policy(GTK_WINDOW(window), FALSE, FALSE, TRUE);
   gtk_widget_realize(window);
-  gtk_signal_connect(GTK_OBJECT(window), "delete_event", GTK_SIGNAL_FUNC(quit_game_cb), NULL);
+  g_signal_connect(G_OBJECT(window), "delete_event", G_CALLBACK(quit_game_cb), NULL);
 }
 
 gint expose_space(GtkWidget *widget, GdkEventExpose *event){ 
-  gdk_draw_pixmap(widget->window, 
+  gdk_draw_drawable(widget->window, 
 		  widget->style->fg_gc[GTK_WIDGET_STATE(widget)], 
 		  buffer, event->area.x, event->area.y, 
 		  event->area.x, event->area.y, 
@@ -294,7 +302,6 @@ gint button_motion_space(GtkWidget *widget, GdkEventButton *event){
 void gui_draw_pixmap(GdkPixmap *target, gint x, gint y){
   int which,xadd,yadd;
   GdkGC *gc;
-  GdkRectangle area;
 
   which = tiles[y][x].status;
 
@@ -311,12 +318,12 @@ void gui_draw_pixmap(GdkPixmap *target, gint x, gint y){
     gdk_window_set_back_pixmap(mover.window, mover.pixmap, 0);
   }
 
-  gdk_draw_pixmap(target, gc, tiles_pixmap,
+  gdk_draw_drawable(target, gc, tiles_pixmap,
 		  which * TILE_SIZE, 0, 
 		  xadd, yadd, TILE_SIZE, TILE_SIZE);
   if(which == USED){
     /* North */
-    gdk_draw_pixmap(target,
+    gdk_draw_drawable(target,
 		    gc,
 		    tiles_pixmap,
 		    tiles[y][x].n * 10,
@@ -327,7 +334,7 @@ void gui_draw_pixmap(GdkPixmap *target, gint x, gint y){
 		    13);
   
     /* South */
-    gdk_draw_pixmap(target,
+    gdk_draw_drawable(target,
 		    gc,
 		    tiles_pixmap,
 		    tiles[y][x].s * 10,
@@ -338,7 +345,7 @@ void gui_draw_pixmap(GdkPixmap *target, gint x, gint y){
 		    13);
     
     /* West */
-    gdk_draw_pixmap(target,
+    gdk_draw_drawable(target,
 		    gc,
 		    tiles_pixmap,
 		    tiles[y][x].w * 10,
@@ -349,7 +356,7 @@ void gui_draw_pixmap(GdkPixmap *target, gint x, gint y){
 		    13);
   
     /* East */
-    gdk_draw_pixmap(target,
+    gdk_draw_drawable(target,
 		    gc,
 		    tiles_pixmap,
 		    tiles[y][x].e * 10,
@@ -359,14 +366,10 @@ void gui_draw_pixmap(GdkPixmap *target, gint x, gint y){
 		    9,
 		    13);
   }
-  area.x = xadd;
-  area.y = yadd;
-  area.width = TILE_SIZE;
-  area.height = TILE_SIZE;
-  gtk_widget_draw (space, &area);
+  gtk_widget_queue_draw_area (space, xadd, yadd, TILE_SIZE, TILE_SIZE);
 
   if(target==mover.pixmap)
-    gdk_gc_destroy(gc);
+    gdk_gc_unref(gc);
 }
 
 void get_pixeltilexy(int x,int y,int *xx,int *yy){
@@ -415,7 +418,7 @@ int setup_mover(int x,int y,int status){
     mover.xstart = xx; mover.ystart = yy;
     gdk_window_resize(mover.window, TILE_SIZE, TILE_SIZE);
     mover.pixmap = gdk_pixmap_new(mover.window, TILE_SIZE,TILE_SIZE,
-				  gdk_window_get_visual(mover.window)->depth);
+				  gdk_drawable_get_visual(mover.window)->depth);
     gdk_window_move(mover.window,x - mover.xoff,y - mover.yoff);
     gui_draw_pixmap(mover.pixmap,xx,yy);
     gdk_window_show(mover.window);
@@ -437,11 +440,11 @@ int setup_mover(int x,int y,int status){
       gui_draw_pixmap(buffer,mover.xstart,mover.ystart);
     }
     gdk_window_hide(mover.window);
-    if(mover.pixmap) gdk_pixmap_unref(mover.pixmap);
+    if(mover.pixmap) gdk_drawable_unref(mover.pixmap);
     mover.pixmap = NULL;
     if(game_over()){
       paused = 1;
-      gtk_clock_stop(GTK_CLOCK(timer));
+      games_clock_stop(GAMES_CLOCK(timer));
       if(!have_been_hinted){
 	message(_("Puzzle solved! Well done!"));
 	game_score();
@@ -535,8 +538,8 @@ void game_score(){
   gchar level[5];
   
   sprintf(level,"%dx%d",SIZE,SIZE);
-  seconds = GTK_CLOCK(timer)->stopped;
-  gtk_clock_set_seconds(GTK_CLOCK(timer), (int) seconds);
+  seconds = GAMES_CLOCK(timer)->stopped;
+  games_clock_set_seconds(GAMES_CLOCK(timer), (int) seconds);
   score = (gfloat) (seconds / 60) + (gfloat) (seconds % 60) / 100;
   pos = gnome_score_log(score,level,FALSE);
   gnome_scores_display (_(APPNAME_LONG), APPNAME, level, pos);
@@ -551,8 +554,13 @@ gint configure_space(GtkWidget *widget, GdkEventConfigure *event){
 void redraw_all(){
   guint x, y;
   GdkGC *draw_gc;
+  GdkRegion *region;
+
+  region = gdk_drawable_get_clip_region(GDK_DRAWABLE(space->window));
+  gdk_window_begin_paint_region(space->window, region); 
+
   draw_gc = gdk_gc_new(space->window);
-  get_bg_color(); 
+  get_bg_color();
   gdk_window_set_background(space->window, &bg_color);
   gdk_gc_set_background(draw_gc,&bg_color);
   gdk_gc_set_foreground(draw_gc,&bg_color);
@@ -563,36 +571,46 @@ void redraw_all(){
       gui_draw_pixmap(buffer, x, y);
   if(draw_gc)
     gdk_gc_unref(draw_gc);
+
+  gdk_window_end_paint(space->window);
+  gdk_region_destroy(region);
 }
 
 void redraw_left(){
   int x,y;
+  GdkRegion *region;
+  GdkRectangle rect ={x:CORNER, y:CORNER, width:TILE_SIZE*SIZE,
+		     height:TILE_SIZE*SIZE};
+
+  region = gdk_region_rectangle(&rect);
+
+  gdk_window_begin_paint_region(space->window, region); 
+
   for(y = 0; y < SIZE; y++)
     for(x = 0; x < SIZE; x++)
       gui_draw_pixmap(buffer, x, y);
+
+  gdk_window_end_paint(space->window);
+  gdk_region_destroy(region);
 }
 
 void create_space(){
-  gtk_widget_push_visual(gdk_imlib_get_visual());
-  gtk_widget_push_colormap(gdk_imlib_get_colormap());
   space = gtk_drawing_area_new();
-  gtk_widget_pop_colormap();
-  gtk_widget_pop_visual();
   gnome_app_set_contents(GNOME_APP(window),space);
   gtk_drawing_area_size(GTK_DRAWING_AREA(space),CORNER*2 + GAP+ SIZE*TILE_SIZE*2,SIZE*TILE_SIZE + CORNER*2);
   gtk_widget_set_events(space, GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK | GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK);
   gtk_widget_realize(space);
   
-  gtk_signal_connect(GTK_OBJECT(space), "expose_event", 
-		     GTK_SIGNAL_FUNC(expose_space), NULL);
-  gtk_signal_connect(GTK_OBJECT(space), "configure_event", 
-		     GTK_SIGNAL_FUNC(configure_space), NULL);
-  gtk_signal_connect(GTK_OBJECT(space), "button_press_event", 
-		     GTK_SIGNAL_FUNC(button_press_space), NULL);
-  gtk_signal_connect (GTK_OBJECT(space),"button_release_event",
-                      GTK_SIGNAL_FUNC(button_release_space), NULL);
-  gtk_signal_connect (GTK_OBJECT(space), "motion_notify_event",
-                      GTK_SIGNAL_FUNC(button_motion_space), NULL);
+  g_signal_connect (G_OBJECT(space), "expose_event", 
+		    G_CALLBACK(expose_space), NULL);
+  g_signal_connect (G_OBJECT(space), "configure_event", 
+		    G_CALLBACK(configure_space), NULL);
+  g_signal_connect (G_OBJECT(space), "button_press_event", 
+		   G_CALLBACK(button_press_space), NULL);
+  g_signal_connect (G_OBJECT(space),"button_release_event",
+                    G_CALLBACK(button_release_space), NULL);
+  g_signal_connect (G_OBJECT(space), "motion_notify_event",
+                    G_CALLBACK(button_motion_space), NULL);
   gtk_widget_show(space);
 }
 
@@ -600,9 +618,9 @@ void create_space(){
 void create_statusbar(){
   GtkWidget *time_label,*time_box;
   time_box = gtk_hbox_new(0, FALSE);
-  time_label = gtk_label_new (_("Time:"));
+  time_label = gtk_label_new (_("Time : "));
   gtk_box_pack_start (GTK_BOX(time_box), time_label, FALSE, FALSE, 0);
-  timer = gtk_clock_new (GTK_CLOCK_INCREASING);
+  timer = games_clock_new ();
   gtk_box_pack_start (GTK_BOX(time_box), timer, FALSE, FALSE, 0);
   gtk_widget_show (time_label);
   gtk_widget_show (timer);
@@ -631,8 +649,8 @@ void create_mover(){
   attributes.event_mask = 0;
   attributes.width = TILE_SIZE;
   attributes.height = TILE_SIZE;
-  attributes.colormap = gdk_window_get_colormap (space->window);
-  attributes.visual = gdk_window_get_visual (space->window);
+  attributes.colormap = gdk_drawable_get_colormap (space->window);
+  attributes.visual = gdk_drawable_get_visual (space->window);
   
   mover.window = gdk_window_new(space->window, &attributes,
 			 (GDK_WA_VISUAL | GDK_WA_COLORMAP));
@@ -643,27 +661,21 @@ void load_image(){
 
   char *tmp;
   char *fname;
-  GdkImlibImage *image;
-  GdkVisual *visual;
+  GdkPixbuf *image;
 
   tmp = g_strconcat("gnotravex/", "gnotravex.png", NULL);
-  fname = gnome_unconditional_pixmap_file(tmp);
+  fname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP, (tmp), FALSE, NULL);
   g_free(tmp);
-  if(!g_file_exists(fname)) {
+  if(!g_file_test (fname, G_FILE_TEST_EXISTS)) {
     g_print(N_("Could not find \'%s\' pixmap file\n")\
 	    , fname);
     exit(1);
   }
-  image = gdk_imlib_load_image(fname);
+  image = gdk_pixbuf_new_from_file(fname, NULL);
 
-  visual = gdk_imlib_get_visual();
-  if(visual->type != GDK_VISUAL_TRUE_COLOR) {
-    gdk_imlib_set_render_type(RT_PLAIN_PALETTE);
-  }
-  gdk_imlib_render(image, image->rgb_width, image->rgb_height);
-  tiles_pixmap = gdk_imlib_move_image(image);
-  
-  gdk_imlib_destroy_image(image);
+  gdk_pixbuf_render_pixmap_and_mask (image, &tiles_pixmap, NULL, 127);
+
+  gdk_pixbuf_unref (image);
   g_free(fname);
 }
 
@@ -733,9 +745,9 @@ void new_board(int size){
 
 void get_bg_color(){
   GdkImage *tmpimage;
-  tmpimage = gdk_image_get(tiles_pixmap, 0, 0, 9, 6);
+  tmpimage = gdk_drawable_get_image(tiles_pixmap, 0, 0, 9, 6);
   bg_color.pixel = gdk_image_get_pixel(tmpimage, 8, 5);
-  gdk_image_destroy(tmpimage);
+  gdk_image_unref(tmpimage);
 }
 
 void pause_cb(){
@@ -743,17 +755,93 @@ void pause_cb(){
   paused = !paused;
   if(paused){
     message(_("... Game paused ..."));
-    gtk_clock_stop(GTK_CLOCK(timer));
+    gui_draw_pause();
+    games_clock_stop(GAMES_CLOCK(timer));
   } else {
     message("");
-    gtk_clock_start(GTK_CLOCK(timer));
+    redraw_all();
+    games_clock_start(GAMES_CLOCK(timer));
   }
 }
 
+void gui_draw_pause(){
+  guint x, y, xadd, yadd, which;
+  GdkRegion *region;
+  GdkGC *gc;
+
+  region = gdk_drawable_get_clip_region(GDK_DRAWABLE(space->window));
+  gdk_window_begin_paint_region(space->window, region);
+
+  for(y = 0; y < SIZE; y++) {
+    for(x = 0; x < SIZE*2; x++) {
+      which = tiles[y][x].status;
+
+      xadd = x * TILE_SIZE + CORNER + (x >= SIZE)*GAP;
+      yadd = y * TILE_SIZE + CORNER;
+      gc = space->style->black_gc;
+
+      gdk_draw_drawable(buffer, gc, tiles_pixmap,
+                      which * TILE_SIZE, 0, 
+                      xadd, yadd, TILE_SIZE, TILE_SIZE);
+
+      if(which == USED) {
+        /* North */
+        gdk_draw_drawable(buffer,
+                        gc,
+                        tiles_pixmap,
+                        0,
+                        TILE_SIZE+1, 
+                        xadd + TILE_SIZE/2-3,
+                        yadd + 5,
+                        9,
+                        13);
+
+        /* South */
+        gdk_draw_drawable(buffer,
+                        gc,
+                        tiles_pixmap,
+                        0,
+                        TILE_SIZE+1, 
+                        xadd + TILE_SIZE/2-3,
+                        yadd + TILE_SIZE-17,
+                        9,
+                        13);
+
+        /* West */
+	gdk_draw_drawable(buffer,
+                        gc,
+                        tiles_pixmap,
+                        0,
+                        TILE_SIZE+1, 
+                        xadd + 5,
+                        yadd + TILE_SIZE/2-6,
+                        9,
+                        13);
+ 
+        /* East */
+        gdk_draw_drawable(buffer,
+                        gc,
+                        tiles_pixmap,
+                        0,
+                        TILE_SIZE+1, 
+                        xadd + TILE_SIZE-13,
+                        yadd + TILE_SIZE/2-6,
+                        9,
+                        13);
+        }
+
+        gtk_widget_queue_draw_area (space, xadd, yadd, TILE_SIZE, TILE_SIZE);
+     }
+  }
+
+  gdk_window_end_paint(space->window);
+  gdk_region_destroy(region);
+}
+
 void timer_start(){
-  gtk_clock_stop(GTK_CLOCK(timer));
-  gtk_clock_set_seconds(GTK_CLOCK(timer), 0);
-  gtk_clock_start(GTK_CLOCK(timer));
+  games_clock_stop(GAMES_CLOCK(timer));
+  games_clock_set_seconds(GAMES_CLOCK(timer), 0);
+  games_clock_start(GAMES_CLOCK(timer));
 }
 
 /* --------------------------- MENU --------------------- */
@@ -764,7 +852,7 @@ void create_menu(){
 void make_buffer (GtkWidget *widget) {
 
   if(buffer)
-    gdk_pixmap_unref(buffer);
+    gdk_drawable_unref(buffer);
   
   buffer = gdk_pixmap_new(widget->window, widget->allocation.width, widget->allocation.height, -1);
 
@@ -775,9 +863,11 @@ void new_game_cb(GtkWidget *widget, gpointer data){
   widget = space;
   
   new_board(SIZE);
+  gtk_widget_freeze_child_notify(space);
   gtk_drawing_area_size(GTK_DRAWING_AREA(space),CORNER*2 + GAP+ SIZE*TILE_SIZE*2,SIZE*TILE_SIZE + CORNER*2);
   make_buffer(widget);
   redraw_all();
+  gtk_widget_thaw_child_notify(space);
   paused = 0;
   timer_start();
   sprintf(str,_("Playing %dx%d board"),SIZE,SIZE);
@@ -786,42 +876,37 @@ void new_game_cb(GtkWidget *widget, gpointer data){
 
 void quit_game_cb(GtkWidget *widget, gpointer data){
   if(buffer)
-    gdk_pixmap_unref(buffer);
+    gdk_drawable_unref(buffer);
   if(tiles_pixmap)
-    gdk_pixmap_unref(tiles_pixmap);
+    gdk_drawable_unref(tiles_pixmap);
   if(mover.pixmap)
-    gdk_pixmap_unref(mover.pixmap);
+    gdk_drawable_unref(mover.pixmap);
 
   gtk_main_quit();
 }
 
-static char *nstr(int n){
-  char buf[20]; sprintf(buf, "%d", n);
-  return strdup(buf);
-}
-
 static int save_state(GnomeClient *client,gint phase, 
 		      GnomeRestartStyle save_style, gint shutdown,
 		      GnomeInteractStyle interact_style, gint fast,
 		      gpointer client_data){
   char *argv[20];
   int i;
-  gint xpos, ypos;
+  int xpos, ypos;
   
   gdk_window_get_origin(window->window, &xpos, &ypos);
   
   i = 0;
   argv[i++] = (char *)client_data;
   argv[i++] = "-x";
-  argv[i++] = nstr(xpos);
+  argv[i++] = g_strdup_printf("%d",xpos);
   argv[i++] = "-y";
-  argv[i++] = nstr(ypos);
+  argv[i++] = g_strdup_printf("%d",ypos);
 
   gnome_client_set_restart_command(client, i, argv);
   gnome_client_set_clone_command(client, 0, NULL);
   
-  free(argv[2]);
-  free(argv[4]);
+  g_free(argv[2]);
+  g_free(argv[4]);
   
   return TRUE;
 }
@@ -960,14 +1045,38 @@ void solve_cb(GtkWidget *widget, gpointer data){
 
 void about_cb(GtkWidget *widget, gpointer data){
   GtkWidget *about;
+  GdkPixbuf *pixbuf = NULL;
   
   const gchar *authors[] = { "Lars Rydlinge", NULL };
+  gchar *documenters[] = {
+                          NULL
+                          };
+  /* Translator credits */
+  gchar *translator_credits = _("translator_credits");
+
+  {
+	  char *filename = NULL;
+
+	  filename = gnome_program_locate_file (NULL,
+			  GNOME_FILE_DOMAIN_APP_PIXMAP,
+			  "gnotravex/gnome-gnotravex.png",
+			  TRUE, NULL);
+	  if (filename != NULL)
+	  {
+		  pixbuf = gdk_pixbuf_new_from_file(filename, NULL);
+		  g_free (filename);
+	  }
+  }
+
   about = gnome_about_new(_(APPNAME_LONG), 
 			  GNOTRAVEX_VERSION, 
 			  "(C) 1998 Lars Rydlinge",
-			  (const char **)authors, 
 			  _("Tetravex clone\n(Comments to: Lars.Rydlinge@HIG.SE)"), 
-			  NULL);
+			  (const char **)authors,
+                          (const char **)documenters,
+                          strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+			  pixbuf);
+  gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (window));
   gtk_widget_show(about);
 }
 
